@@ -175,8 +175,8 @@ class DimArray(object):
 	    axes = values.axes
 
 	# default options
-	if _indexing is None: _indexing = get_option('indexing')
-	if _indexing_broadcast is None: _indexing_broadcast = get_option('indexing_broadcast')
+	if _indexing is None: _indexing = get_option('indexing.by')
+	if _indexing_broadcast is None: _indexing_broadcast = get_option('indexing.broadcast')
 
 	#
 	# array values
@@ -395,10 +395,11 @@ mismatch between values and axes""".format(inferred, self.values.shape)
     def dtype(self): 
 	return self.values.dtype
 
+    @property
     def __array__(self): 
 	""" so that np.array() works as expected (returns values)
 	"""
-	return self.values
+	return self.values.__array__
 
     def __array_wrap__(self, result): 
 	""" returns a DimArray when doing e.g. self.values + self
@@ -765,11 +766,11 @@ mismatch between values and axes""".format(inferred, self.values.shape)
 	>>> np.all(s == 5*a)
 	True
 	"""
-	result = _operation.operation(func, self, other, broadcast=get_option('op_broadcast'), reindex=get_option('op_reindex'), constructor=self._constructor)
+	result = _operation.operation(func, self, other, broadcast=get_option('op.broadcast'), reindex=get_option('op.reindex'), constructor=self._constructor)
 	return result
 
     def _roperation(self, func, other):
-	return _operation.operation(func, other, self, broadcast=get_option('op_broadcast'), reindex=get_option('op_reindex'), constructor=self._constructor)
+	return _operation.operation(func, other, self, broadcast=get_option('op.broadcast'), reindex=get_option('op.reindex'), constructor=self._constructor)
 
     def __neg__(self): return self._constructor(-self.values, self.axes)
     def __pos__(self): return self._constructor(+self.values, self.axes)
@@ -999,10 +1000,10 @@ mismatch between values and axes""".format(inferred, self.values.shape)
 	>>> s = pd.Series([3,5,6], index=['a','b','c'])
 	>>> s.index.name = 'dim0'
 	>>> DimArray.from_pandas(s)
-	dimarray: 3 non-null elements (0 null)
-	dimensions: 'dim0'
-	0 / dim0 (3): a to c
-	array([3, 5, 6], dtype=int64)
+        dimarray: 3 non-null elements (0 null)
+        dimensions: 'dim0'
+        0 / dim0 (3): a to c
+        array([3, 5, 6])
 
 	Also work with Multi-Index
 	>>> panel = pd.Panel(np.arange(2*3*4).reshape(2,3,4))
@@ -1163,7 +1164,7 @@ mismatch between values and axes""".format(inferred, self.values.shape)
 	    line = repr(self.axes)
 	    lines.append(line)
 
-	if self.size < get_option('display_max'):
+	if self.size < get_option('display.max'):
 	    line = repr(self.values)
 	else:
 	    line = "array(...)"
